/*
  detector.c -- alloc/free detector
  Copyright (C) 2007-2014 Dieter Baron and Thomas Klausner

  This file is part of ckmame, a program to check rom sets for MAME.
  The authors can be contacted at <ckmame@nih.at>

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.
  3. The name of the author may not be used to endorse or promote
     products derived from this software without specific prior
     written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
  IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#include <stdlib.h>

#include "detector.h"
#include "xmalloc.h"


void
detector_free(detector_t *d) {
    if (d == NULL) {
	return;
    }
    free(d->name);
    free(d->author);
    free(d->version);
    array_free(d->rules, detector_rule_finalize);
    free(d->buf);
    free(d);
}


detector_t *
detector_new(void) {
    detector_t *d;

    d = xmalloc(sizeof(*d));

    d->name = NULL;
    d->author = NULL;
    d->version = NULL;
    d->rules = array_new(sizeof(detector_rule_t));
    d->buf = NULL;
    d->buf_size = 0;

    return d;
}


void
detector_rule_finalize(detector_rule_t *dr) {
    array_free(dr->tests, detector_test_finalize);
}


void
detector_test_finalize(detector_test_t *dt) {
    free(dt->mask);
    free(dt->value);
}
